@@ -12,10 +12,16 @@ class HyperChat:
         self.api = API(self.host, self.token, ssl_active=self.ssl)
         self.chat_manager = None
 
-    def run(self, app_functions):
-        self.rutas = app_functions
+    def run(self):
         self.chat_manager = ChatManager(self, self.host, self.token, self.api.lista_canales(), ssl_active=self.ssl)
 
+    def route(self, command):
+        def decorator(func):
+            def wrapper(*args, **kwargs):
+                func(args, kwargs)
+            self.rutas[command] = wrapper
+        return decorator
+
     def send(self, request, mensaje):
         token = request.get("channel")
         chat = self.chat_manager.chat(token)
